datatype.uuid.core


uuid-patternclj

source

uuid-string?clj

(uuid-string? value)

Returns true if the provided value is a string representing a UUID, else returns false.

Returns true if the provided value is a string representing a UUID,
else returns false.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries